# Copyright (C) Arman Ordookhani <arman.ordookhani@gmail.com> and the Homa team
# http://wiki.hezardastan.org/Homa
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA 02111-1307 USA

# Simple usage:
#
# import GUIBuilder
#
# gui = GUIBuilder.GUI()
#
# gui.btnAbout.connect('clicked', self.onBtnAboutClick)
# gui.btnUpgrade.connect('clicked', self.onBtnUpgradeClick)
# gui.btnInstall.connect('clicked', self.onBtnInstallClick)
#
# install(gui.selectedPackages)
#

import pygtk
pygtk.require('2.0')
import gtk
import PackagesList

class GUI:
	def __init__(self):
		self.selectedPackages = []
		self.createGUI()
    
	def createGUI(self):
		self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
		
		#self.window.set_resizable(False)
		self.window.set_title("Homa multimedia edition for Ubuntu Feisty Fawn (7.04)")
		self.window.connect("delete_event", self.onDelete)
		self.window.set_border_width(10)
		self.window.set_default_size(800, 600)
		self.window.set_icon_from_file('./pixmaps/HomaLogo.png')

		mainbox = gtk.VBox(False)
		self.window.add(mainbox)

		logo = gtk.Image()
		logo.set_from_file("HomaLogo.png")
		logo.show()
		mainbox.pack_start(logo, False, False)
	
		self.notebook = gtk.Notebook()
	
		# This is the main part of program
		# iterate through categories and Pages
		# in Notebook then for each of them
		# create checkButtons
		for cat in PackagesList.Packages.categories:
			scrollwin = gtk.ScrolledWindow()
			scrollwin.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)

			box = gtk.VBox(False)

			for pac in PackagesList.Packages.packages[cat]:
				check = gtk.CheckButton(PackagesList.Packages.descriptions[pac])
				check.Name = pac
				if pac in PackagesList.Packages.installed:
					check.set_sensitive(False)
				check.connect('clicked', self.onChecksClick)
				check.show()			
				box.pack_start(check, False, False, 2)

			box.show()

			scrollwin.add_with_viewport(box)
			scrollwin.show()

			label = gtk.Label(cat)

			self.notebook.insert_page(scrollwin, label)
    
		self.notebook.show()

		mainbox.pack_start(self.notebook)
		
		btnBox1 = gtk.HBox(False, 350)
		
		self.btnAbout = gtk.Button(None, gtk.STOCK_ABOUT)
		self.btnAbout.show()
		btnBox1.pack_start(self.btnAbout)
		
		btnBox2 = gtk.HBox(True, 10)
	
		btnCancel = gtk.Button(None, gtk.STOCK_CANCEL)
		btnCancel.show()
		btnCancel.connect('clicked', lambda w: gtk.main_quit())
		btnBox2.pack_end(btnCancel)

		self.btnUpgrade = gtk.Button("Upgrade")
		self.btnUpgrade.show()
		btnBox2.pack_start(self.btnUpgrade)
		
		self.btnInstall = gtk.Button("Install")
		self.btnInstall.show()
		btnBox2.pack_start(self.btnInstall)
			
		btnBox2.show()
		btnBox1.pack_start(btnBox2)
		
		btnBox1.show()
		mainbox.pack_start(btnBox1, False, False, 10)
		
		mainbox.show()
		
		self.window.show()

	def onDelete(self, widget, event, data = None):
		gtk.main_quit()
		return False

	def onChecksClick(self, widget, data = None):
		if widget.get_active() == True:
			self.selectedPackages.append(widget.Name)
		else:
			self.selectedPackages.remove(widget.Name)

	def main(self):
		gtk.main()

