# Copyright (C) Arman Ordookhani <arman.ordookhani@gmail.com> and the Homa team
# http://wiki.hezardastan.org/Homa
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA 02111-1307 USA


#
# Simple usage:
#
# import PackagesList
#
# packs = Packages(filename)
# packs.parse()
#
# now you have
# Packages.categories : Name of categories in order that appeared in config file
# Packages.packages : Dictonary that list packages in categories
# Packages.dependencies : Packages to be installed
# Packages.descriptions : Short description of the package
#

import os

class Packages:
	categories = []
	packages = {}
	dependencies = {}
	descriptions = {}
	installed = []
    
	def __init__(self, filename):
		self.f = file(filename)
		self.lineNumber = 0
    
    # read a line from file and remove comment and 
    # extra spaces
	def readline(self):
		self.lineNumber = self.lineNumber + 1

		s = self.f.readline()
	
		end = s.find(";")
		if end == -1:
			end = len(s)
	
		s = s[:end].strip()
		return s

    #like readline but don't return empty strings
	def getline(self):
		s = ""
		while s == "":
			s = self.readline()
		return s	

	def parse(self):
		currentCategory = "NOT SELECTED"
		while True:
			s = self.getline()

			if s == "#EOF":
				break
			elif s[0] == "#":
				currentCategory = s[1:]
				self.categories.append(currentCategory)
				self.packages[currentCategory] = []
			else:
				self.packages[currentCategory].append(s)

				x = self.getline().split()
				if x[0] == "NONE":
					self.dependencies[s] = []
				else:
					self.dependencies[s] = x

				self.descriptions[s] = self.getline()

	def testInstalled(self):
		proc = os.popen("dpkg-query -f='${Package} ${Status}\n' -W | sed -n 's/ install ok installed$//p'", "r")
		installList = []
		for packName in proc:
			installList.append(packName[:-1])
		installList = set(installList)

		for packName in Packages.dependencies:
			if len(Packages.dependencies[packName]) == 0:
				continue
			for req in Packages.dependencies[packName]:
				if not req in installList:
					break
			else:
				self.installed.append(packName)
		print "Installed Packages: ", Packages.installed
		Packages.installed = set(Packages.installed) # for fast membership testing

