#!/usr/bin/env python
#
# Copyright (C) Arman Ordookhani <arman.ordookhani@gmail.com> and the Homa team
# http://wiki.hezardastan.org/Homa
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA 02111-1307 USA

# Script to convert GUI + Code format into new format

import gtk, gtk.glade

class MakeGui:

    def __init__(self):
        self.gui = gtk.glade.XML('homa.glade')

        self.categories = {}
        self.categories["system"] = ("sourceslist", "nautilusopenterminal", "extrafonts", "persianfonts", "bum", "gparted", "firestarter", "rar", "7zip", "buildessential", "alien", "gnomeschedule", "wine", "ntfs", "nvidia", "ati", "beryl", "numlock", "ctrlaltdel")
        self.categories["accessories"] = ("mc", "gnomebaker", "graveman", "zekr", "jcal", "devede", "gdesklets", "xfardic", "beagle", "revelation", "seahorse")
        self.categories["multimedia"] = ("freecodecs", "bincodecs", "libdvdcss", "mplayer", "smplayer", "exaile", "xineui", "vlc", "xmms", "bmp", "realplay", "cowbell", "streamtunner", "kino", "audacity", "goobox", "banshee", "id3", "avidemux")
        self.categories["web"] = ("opera", "epiphany", "thunderbird", "flash", "java", "video", "d4x", "xchat", "xchatgnome", "amule", "gftp", "liferea", "pidgin", "wireshark", "mailnotify")
        self.categories["office"] = ("gnucash", "grisbi", "scribus", "planner")
        self.categories["graphics"] = ("xchm", "dia", "gqview", "inkscape", "blender")
        self.categories["programming"] = ("bluefish", "vim", "kompozer", "gtranslator")
        self.categories["servers"] = ("clamav", "clamtk", "samba", "bind9", "lamp", "virtualbox")

        self.packages = {}
        self.packages["sourceslist"] = []
        self.packages["extrafonts"] = ["gsfonts-x11"]
        self.packages["persianfonts"] = ("ttf-farsiweb", "ttf-freefarsi")
        self.packages["bum"] = ["bum"]
        self.packages["gparted"] = ["gparted"]
        self.packages["firestarter"] = ["firestarter"]
        self.packages["rar"] = ("rar", "unrar")
        self.packages["7zip"] = ("p7zip-full", "p7zip")
        self.packages["buildessential"] = ["build-essential"]
        self.packages["alien"] = ["alien"]
        self.packages["gnomeschedule"] = ["gnome-schedule"]
        self.packages["wine"] = ["wine"]
        self.packages["ntfs"] = ["ntfs-config"]
        self.packages["nvidia"] = ("nvidia-glx", "nvidia-kernel-common")
        self.packages["ati"] = ("xorg-driver-fglrx", "fglrx-control")
        self.packages["beryl"] = ("beryl", "beryl-manager", "emerald-themes")
        self.packages["numlock"] = ["numlockx"]
        self.packages["ctrlaltdel"] = []
        self.packages["mc"] = ["mc"]
        self.packages["gnomebaker"] = ["gnomebaker"]
        self.packages["graveman"] = ["graveman"]
        self.packages["zekr"] = ("zekr", "ttf-scheherazade", "ttf-me-quran", "ttf-farsiweb", "ttf-arabeyes")
        self.packages["jcal"] = ["jalali-calendar"]
        self.packages["devede"] = ["devede"]
        self.packages["gdesklets"] = ("gdesklets", "gdesklets-data")
        self.packages["xfardic"] = ("libwxgtk2.6-0", "xfardic", "xfardic-xdb-gnulinux")
        self.packages["beagle"] = ["beagle"]
        self.packages["revelation"] = ["revelation"]
        self.packages["seahorse"] = ["seahorse"]
        self.packages["freecodecs"] = ("gstreamer0.10-ffmpeg", "gstreamer0.10-gl", "gstreamer0.10-plugins-base", "libxvidcore4", "gstreamer0.10-plugins-good", "gstreamer0.10-plugins-bad", "gstreamer0.10-plugins-bad-multiverse", "gstreamer0.10-plugins-ugly", "gstreamer0.10-plugins-ugly-multiverse", "libxine-main1", "libxine-extracodecs", "faad", "sox", "ffmpeg", "mjpegtools", "vorbis-tools", "lame")
        self.packages["bincodecs"] = ("gstreamer0.10-pitfdll", "w32codecs")
        self.packages["libdvdcss"] = ("libdvdcss2", "libdvdread3")
        self.packages["mplayer"] = ("mplayer", "mplayer-fonts", "mplayer-skins")
        self.packages["smplayer"] = ["smplayer"]
        self.packages["exaile"] = ["exaile"]
        self.packages["xineui"] = ("xine-ui", "libxine-extracodecs")
        self.packages["vlc"] = ("vlc", "vlc-plugin-*", "mozilla-plugin-vlc", "avahi-daemon", "avahi-utils")
        self.packages["xmms"] = ("xmms", "xmms-skins", "xmms-status-plugin", "xmms-wma")
        self.packages["bmp"] = ("beep-media-player", "bmp-crossfade", "bmp-mp4", "beep-media-player-wma")
        self.packages["realplay"] = ["realplay"]
        self.packages["cowbell"] = ["cowbell"]
        self.packages["streamtunner"] = ("streamtuner", "streamripper")
        self.packages["kino"] = ("kino", "kinoplus")
        self.packages["audacity"] = ["audacity"]
        self.packages["goobox"] = ["goobox"]
        self.packages["banshee"] = ["banshee"]
        self.packages["id3"] = ["easytag"]
        self.packages["avidemux"] = ["avidemux"]
        self.packages["opera"] = ("libqt3-mt", "opera")
        self.packages["epiphany"] = ("epiphany-browser", "epiphany-extensions")
        self.packages["thunderbird"] = ["mozilla-thunderbird"]
        self.packages["flash"] = ("gsfonts-x11", "flashplugin-nonfree")
        self.packages["java"] = ("sun-java6-jre", "sun-java6-plugin", "sun-java6-fonts")
        self.packages["video"] = ["mozilla-mplayer"]
        self.packages["d4x"] = ["d4x"]
        self.packages["xchat"] = ["xchat"]
        self.packages["xchatgnome"] = ["xchat-gnome"]
        self.packages["amule"] = ("amule", "amule-utils", "amule-utils-gui")
        self.packages["gftp"] = ["gftp"]
        self.packages["liferea"] = ["liferea"]
        self.packages["pidgin"] = ["pidgin"]
        self.packages["wireshark"] = ["wireshark"]
        self.packages["mailnotify"] = ["mail-notification"]
        self.packages["gnucash"] = ["gnucash"]
        self.packages["grisbi"] = ["grisbi"]
        self.packages["scribus"] = ["scribus"]
        self.packages["planner"] = ["planner"]
        self.packages["xchm"] = ["xchm"]
        self.packages["dia"] = ["dia-gnome"]
        self.packages["gqview"] = ["gqview"]
        self.packages["inkscape"] = ["inkscape"]
        self.packages["blender"] = ["blender"]
        self.packages["bluefish"] = ["bluefish"] 
        self.packages["vim"] = ["vim"]
        self.packages["kompozer"] = ["kompozer"]
        self.packages["gtranslator"] = ["gtranslator"]
        self.packages["clamav"] = ["clamav"]
        self.packages["clamtk"] = ("clamav", "clamtk")
        self.packages["samba"] = ("samba", "smbfs")
        self.packages["bind9"] = ["bind9"]
        self.packages["lamp"] = ("apache2", "php5", "mysql-server", "libapache2-mod-auth-mysql", "php5-mysql")
        self.packages["virtualbox"] = ["virtualbox"]


    def write(self, filename):
		out = file(filename, "w")

		for cat in self.categories:
			out.write('\n#' + cat + '\n')
			for pack in self.categories[cat]:
				out.write('\n' + pack + '\n')
				if pack in self.packages:

					if len(self.packages[pack]) == 0:
						out.write('NONE')

					for req in self.packages[pack]:
						out.write(req + ' ')

					out.write('\n')
				else:
					out.write('NONE\n')
				out.write(ui.gui.get_widget(pack).get_label() + '\n')

		out.write('\n#EOF\n')

if __name__ == "__main__":
    ui = MakeGui()
    ui.write("Export")

