#!/usr/bin/python2.5
# -*- coding: utf-8 -*-
# vim:set sts=4:tabstop=4:expandtab:shiftwidth=4:
# Copyright (C) Mehdi Hassanpour<mehdi@hezardastan.org> and the Homa team
# http://wiki.hezardastan.org/Homa
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA 02111-1307 USA

import os, sys
import gettext
import gtk, gtk.glade
import shutil
import subprocess
import time
import locale
import detect

APPNAME="Homa"
APPVERSION="7.04.1"

DIR = "i18n"
locale.setlocale(locale.LC_ALL, '')
_ = gettext.gettext
gtk.glade.bindtextdomain(APPNAME, DIR)
gtk.glade.textdomain(APPNAME)
gettext.install(APPNAME, DIR, unicode=1)


class Utils:

    def __init__(self):
        """ To create the time string for backup
        """
        self.t = ""
        for part in time.localtime():
            self.t +=  "-" + str(part)
    
    def cp(self, In = None, Out = None):
        """ Copy a file and make a time based backup of the previous
        """
        shutil.move(Out, Out + self.t)
        shutil.copy(In, os.path.split(Out)[0])
    
    def bck(self, File = None):
        shutil.copy(File, File + self.t)

    def bckdir(self, Dir = None):
        shutil.copytree(Dir, Dir + self.t)
    
class PackageManager:
    confdir = os.path.join(os.path.split(os.path.abspath(sys.argv[0]))[0],'conf')
    
    def __init__(self):
        """ Call Synaptic with different configuration options """
       # Hardcoding 
        self.manager = ["/usr/sbin/synaptic", "--hide-main-window", "--non-interactive"] 
        self.manager.append("-o=dir::etc="+PackageManager.confdir)
        self.manager.append("-o=dir::etc::sourcelist=homacd-sources.list")
    
    def update(self):
        """ Get the last packages list from repositories
        """
        self.manager.append("--update-at-startup")
        retcode = subprocess.Popen(self.manager).wait()
        #print "Synaptic exited with return code = ",retcode

        #subprocess.call(self.manager)

    def upgrade(self):
        """ Get and Install the last packages from repositories
        """
        self.manager.append("--upgrade-mode")
        retcode = subprocess.Popen(self.manager).wait()

    def install(self, Packages = None):
        """ Install packages
        """
        self.manager.append("--set-selections")
        f = os.popen(" ".join(self.manager), "w")
        for s in Packages:
            f.write("%s                 install\n" % s)
        f.close()

class MakeGui:

    def __init__(self):
	# Hardcoding
        self.gui = gtk.glade.XML(os.path.join(os.path.split(os.path.abspath(sys.argv[0]))[0],'homa.glade'))

        self.gui.get_widget("Homa").connect("delete_event", self.destroy)

        self.categories = {}
        self.categories["system"] = ("sourceslist", "nautilusopenterminal", "extrafonts", "persianfonts", "bum", "gparted", "firestarter", "rar", "7zip", "buildessential", "alien", "gnomeschedule", "wine", "ntfs", "nvidia", "ati", "beryl", "numlock", "ctrlaltdel", "abc")
        self.categories["accessories"] = ("mc", "gnomebaker", "graveman", "zekr", "jcal", "devede", "gdesklets", "xfardic", "beagle", "revelation", "seahorse")
        self.categories["multimedia"] = ("freecodecs", "bincodecs", "libdvdcss", "mplayer", "smplayer", "exaile", "xineui", "vlc", "xmms", "bmp", "realplay", "cowbell", "streamtunner", "kino", "audacity", "goobox", "banshee", "id3", "avidemux")
        self.categories["web"] = ("opera", "epiphany", "thunderbird", "flash", "java", "video", "d4x", "xchat", "xchatgnome", "amule", "gftp", "liferea", "pidgin", "wireshark", "mailnotify")
        self.categories["office"] = ("gnucash", "grisbi", "scribus", "planner")
        self.categories["graphics"] = ("xchm", "dia", "gqview", "inkscape", "blender")
        self.categories["programming"] = ("bluefish", "vim", "kompozer", "gtranslator")
        self.categories["servers"] = ("clamav", "clamtk", "samba", "bind9", "lamp", "virtualbox")

        self.packages = {}
        self.packages["abc"] = ("amule", "mc", "gqview")
        self.packages["sourceslist"] = []
        self.packages["nautilusopenterminal"] = ["nautilus-open-terminal"]
        self.packages["extrafonts"] = ["gsfonts-x11"]
        self.packages["persianfonts"] = ("ttf-farsiweb", "ttf-freefarsi")
        self.packages["bum"] = ["bum"]
        self.packages["gparted"] = ["gparted"]
        self.packages["firestarter"] = ["firestarter"]
        self.packages["rar"] = ("rar", "unrar")
        self.packages["7zip"] = ("p7zip-full", "p7zip")
        self.packages["buildessential"] = ["build-essential"]
        self.packages["alien"] = ["alien"]
        self.packages["gnomeschedule"] = ["gnome-schedule"]
        self.packages["wine"] = ["wine"]
        self.packages["ntfs"] = ["ntfs-config"]
        self.packages["nvidia"] = ("nvidia-glx", "nvidia-kernel-common")
        self.packages["ati"] = ("xorg-driver-fglrx", "fglrx-control")
        self.packages["beryl"] = ("beryl", "beryl-manager", "emerald-themes")
        self.packages["numlock"] = ["numlockx"]
        self.packages["ctrlaltdel"] = []
        self.packages["mc"] = ["mc"]
        self.packages["gnomebaker"] = ["gnomebaker"]
        self.packages["graveman"] = ["graveman"]
        self.packages["zekr"] = ("zekr", "ttf-scheherazade", "ttf-me-quran", "ttf-farsiweb", "ttf-arabeyes")
        self.packages["jcal"] = ["jalali-calendar"]
        self.packages["devede"] = ["devede"]
        self.packages["gdesklets"] = ("gdesklets", "gdesklets-data")
        self.packages["xfardic"] = ("libwxgtk2.6-0", "xfardic", "xfardic-xdb-gnulinux")
        self.packages["beagle"] = ["beagle"]
        self.packages["revelation"] = ["revelation"]
        self.packages["seahorse"] = ["seahorse"]
        self.packages["freecodecs"] = ("gstreamer0.10-ffmpeg", "gstreamer0.10-gl", "gstreamer0.10-plugins-base", "libxvidcore4", "gstreamer0.10-plugins-good", "gstreamer0.10-plugins-bad", "gstreamer0.10-plugins-bad-multiverse", "gstreamer0.10-plugins-ugly", "gstreamer0.10-plugins-ugly-multiverse", "libxine-main1", "libxine-extracodecs", "faad", "sox", "ffmpeg", "mjpegtools", "vorbis-tools", "lame")
        self.packages["bincodecs"] = ("gstreamer0.10-pitfdll", "w32codecs")
        self.packages["libdvdcss"] = ("libdvdcss2", "libdvdread3")
        self.packages["mplayer"] = ("mplayer", "mplayer-fonts", "mplayer-skins")
        self.packages["smplayer"] = ["smplayer"]
        self.packages["exaile"] = ["exaile"]
        self.packages["xineui"] = ("xine-ui", "libxine-extracodecs")
        self.packages["vlc"] = ("vlc", "vlc-plugin-*", "mozilla-plugin-vlc", "avahi-daemon", "avahi-utils")
        self.packages["xmms"] = ("xmms", "xmms-skins", "xmms-status-plugin", "xmms-wma")
        self.packages["bmp"] = ("beep-media-player", "bmp-crossfade", "bmp-mp4", "beep-media-player-wma")
        self.packages["realplay"] = ["realplay"]
        self.packages["cowbell"] = ["cowbell"]
        self.packages["streamtunner"] = ("streamtuner", "streamripper")
        self.packages["kino"] = ("kino", "kinoplus")
        self.packages["audacity"] = ["audacity"]
        self.packages["goobox"] = ["goobox"]
        self.packages["banshee"] = ["banshee"]
        self.packages["id3"] = ["easytag"]
        self.packages["avidemux"] = ["avidemux"]
        self.packages["opera"] = ("libqt3-mt", "opera")
        self.packages["epiphany"] = ("epiphany-browser", "epiphany-extensions")
        self.packages["thunderbird"] = ["mozilla-thunderbird"]
        self.packages["flash"] = ("gsfonts-x11", "flashplugin-nonfree")
        self.packages["java"] = ("sun-java6-jre", "sun-java6-plugin", "sun-java6-fonts")
        self.packages["video"] = ["mozilla-mplayer"]
        self.packages["d4x"] = ["d4x"]
        self.packages["xchat"] = ["xchat"]
        self.packages["xchatgnome"] = ["xchat-gnome"]
        self.packages["amule"] = ("amule", "amule-utils", "amule-utils-gui")
        self.packages["gftp"] = ["gftp"]
        self.packages["liferea"] = ["liferea"]
        self.packages["pidgin"] = ["pidgin"]
        self.packages["wireshark"] = ["wireshark"]
        self.packages["mailnotify"] = ["mail-notification"]
        self.packages["gnucash"] = ["gnucash"]
        self.packages["grisbi"] = ["grisbi"]
        self.packages["scribus"] = ["scribus"]
        self.packages["planner"] = ["planner"]
        self.packages["xchm"] = ["xchm"]
        self.packages["dia"] = ["dia-gnome"]
        self.packages["gqview"] = ["gqview"]
        self.packages["inkscape"] = ["inkscape"]
        self.packages["blender"] = ["blender"]
        self.packages["bluefish"] = ["bluefish"] 
        self.packages["vim"] = ["vim"]
        self.packages["kompozer"] = ["kompozer"]
        self.packages["gtranslator"] = ["gtranslator"]
        self.packages["clamav"] = ["clamav"]
        self.packages["clamtk"] = ("clamav", "clamtk")
        self.packages["samba"] = ("samba", "smbfs")
        self.packages["bind9"] = ["bind9"]
        self.packages["lamp"] = ("apache2", "php5", "mysql-server", "libapache2-mod-auth-mysql", "php5-mysql")
        self.packages["virtualbox"] = ["virtualbox"]

        self.gui.signal_autoconnect(self);

    def destroy(self, widget, data = None):
        gtk.main_quit()

    def gtk_main_quit(self, gui):
        gtk.main_quit()

    def on_about_clicked(self, gui):
        self.gui.get_widget("aboutdialog").connect("delete_event", self.hidewindow)
        self.gui.get_widget("aboutdialog").show()

    def hidewindow(self, w, event, data=None):
        w.hide()
        return True

    def on_upgrade_clicked(self, gui):
        self.upgrade()

    def upgrade(self):
        self.gui.get_widget("Homa").hide()
        p.upgrade()
        self.gui.get_widget("Homa").show()

    def on_ok_clicked(self, gui):
        self.go()

    def go(self):
        self.gui.get_widget("Homa").hide()
	#p.update()
        d.packages()
        d.configs()
        self.gui.get_widget("Homa").show()

    def on_cancelrepo_clicked(self, gui):
        self.gtk_main_quit(self)

class Do:
    confdir = os.path.join(os.path.split(os.path.abspath(sys.argv[0]))[0],'conf')

    def __init__(self):
        self.p = PackageManager()

    def packages(self):
        """ Install selected packages """

        Packages = []
        for Category in ui.categories:
            for self.element in ui.categories[Category]:
                if ui.gui.get_widget(self.element).get_active() == 1:
                                        Packages.extend(ui.packages[self.element])

        self.p.install(Packages = Packages)

    def configs(self):
        """ Do selected configuration tasks """
        registered = 0
        for Category in ui.categories:
            for self.element in ui.categories[Category]:
                if ui.gui.get_widget(self.element).get_active() == 1:
                    #if (self.element == "freecodecs" or self.element == "bincodecs") and registered != 1:
                        #self.register()
                        #registered = 1

                    if self.element in ("extrafonts", "persianfonts", "xfardic", "sourceslist", "dma", "numlock", "ctrlaltdel"):
			# Unsafe practice
                       try:
                           selfmethod = getattr(self, self.element) # this would now be a reference to e.g. self.midi
                           selfmethod() # call it
                       except:
                           pass

    def register(self):
        """
        Registers gstreamer codecs, need to add dialog/log of command status
        """
        subprocess.Popen(["/usr/bin/gst-register-0.8"]).wait()

    def extrafonts(self):
        """ Install Microsoft Fonts """
        # Hardcoding
        retcode = subprocess.Popen(["tar", "xf", Do.confdir+"/msttcorefonts.tar", "-C", "/usr/share/fonts/truetype/"]).wait()

    def persianfonts(self):
        """ Install Persian Fonts """
        # Hardcoding
        retcode = subprocess.Popen(["mkdir", "/usr/share/fonts/truetype/ttf-persian-fonts/"])
        retcode = subprocess.Popen(["tar", "-zxf", Do.confdir+"/bfonts.tar.gz", "-C", "/usr/share/fonts/truetype/ttf-persian-fonts/"]).wait()
        retcode = subprocess.Popen(["tar", "-zxf", Do.confdir+"/tahoma.tar.gz", "-C", "/usr/share/fonts/truetype/ttf-persian-fonts/"]).wait()

    def xfardic(self):
        """ Install xFarDic Multilingual Dictionary and It's DB files """
        # Hardcoding
        retcode = subprocess.Popen(["tar", "-zxf", Do.confdir+"/generic.xdb.tar.gz", "-C", "/usr/share/xfardic-xdb/"]).wait()
        # Should Be Fixed! # retcode = subprocess.Popen(["cp", Do.confdir+"/xfardic", "/$HOME/xfardic"]).wait()
        #retcode = subprocess.Popen(["cp", Do.confdir+"/xfardic.desktop", "/usr/share/applications/xfardic.desktop"]).wait()

    def sourceslist(self):
        """ Replace the old sources.list by a new one"""
        # Hardcoding
        cmd.cp(Do.confdir+"/sources.list", Out = "/etc/apt/sources.list")

    def dma(self):
        """ Add DMA support to hdparm.conf """
        # Hardcoding
        cmd.cp(Do.confdir+"/hdparm.conf", Out = "/etc/hdparm.conf")

    def numlock(self):
        """ Run numlockx at GDM stratup """
        # Hardcoding
        cmd.cp(Do.confdir+"/numlock-gdm", Out = "/etc/X11/gdm.Init/Default")

    def ctrlaltdel(self):
        """ Run gnome-system-monitor when you type Ctrl+Alt+Del """
        retcode = subprocess.Popen(["gconftool-2", "-t", "str", "--set", "/apps/metacity/global_keybindings/run_command_9", "<Control><Alt>Delete"]).wait()
        #print "gconftool exited with return code = ",retcode
        retcode = subprocess.Popen(["gconftool-2", "-t", "str", "--set", "/apps/metacity/keybinding_commands/command_9", "gnome-system-monitor"]).wait()
        #print "gconftool exited with return code = ",retcode

if __name__ == "__main__":
    basepath = os.path.split(os.path.abspath(sys.argv[0]))[0]
    confdir = os.path.join(basepath,'conf')
    #print basepath,confdir
    detect.replace(confdir)
    cmd = Utils()
    p = PackageManager()
    d = Do()
    ui = MakeGui()
    gtk.main()

