#!/usr/bin/python2.5
# -*- coding: utf-8 -*-
# vim:set sts=4:tabstop=4:expandtab:shiftwidth=4:
# Copyright (C) Mehdi Hassanpour<mehdi@hezardastan.org>,
# Arman Ordookhani <arman.ordookhani@gmail.com> and the Homa team
# http://wiki.hezardastan.org/Homa
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA 02111-1307 USA

import os, sys
import gettext
import shutil
import subprocess
import time
import locale

import detect
import PackagesList
import GUIBuilder

APPNAME="Homa"
APPVERSION="7.04.2"

DIR = "i18n"
locale.setlocale(locale.LC_ALL, '')
_ = gettext.gettext
#gtk.glade.bindtextdomain(APPNAME, DIR)
#gtk.glade.textdomain(APPNAME)
gettext.install(APPNAME, DIR, unicode=1)

class Utils:

    def __init__(self):
        """ To create the time string for backup
        """
        self.t = ""
        for part in time.localtime():
            self.t +=  "-" + str(part)
    
    def cp(self, In = None, Out = None):
        """ Copy a file and make a time based backup of the previous
        """
        shutil.move(Out, Out + self.t)
        shutil.copy(In, os.path.split(Out)[0])
    
    def bck(self, File = None):
        shutil.copy(File, File + self.t)

    def bckdir(self, Dir = None):
        shutil.copytree(Dir, Dir + self.t)
    
class PackageManager:
    confdir = os.path.join(os.path.split(os.path.abspath(sys.argv[0]))[0],'conf')
    
    def __init__(self):
        """ Call Synaptic with different configuration options """
       # Hardcoding 
        self.manager = ["/usr/sbin/synaptic", "--hide-main-window", "--non-interactive"] 
        self.manager.append("-o=dir::etc="+PackageManager.confdir)
        self.manager.append("-o=dir::etc::sourcelist=homacd-sources.list")
    
    def update(self):
        """ Get the last packages list from repositories
        """
        cmd = self.manager
		cmd.append("--update-at-startup")
        retcode = subprocess.Popen(cmd).wait()
        #print "Synaptic exited with return code = ",retcode

        #subprocess.call(self.manager)

    def upgrade(self):
        """ Get and Install the last packages from repositories
        """
		cmd = self.manager
		cmd.append("--upgrade-mode")
        retcode = subprocess.Popen(cmd).wait()

    def install(self, Packages = None):
        """ Install packages
        """
		print "We want to install: ", Packages
        cmd = self.manager
		cmd.append("--set-selections")
        f = os.popen(" ".join(cmd), "w")
        for s in Packages:
            f.write("%s                 install\n" % s)
        f.close()

class MakeGui:
	def __init__(self):
		self.gui = GUIBuilder.GUI()

		self.gui.btnAbout.connect('clicked', self.onBtnAboutClick)
		self.gui.btnUpgrade.connect('clicked', self.onBtnUpgradeClick)
		self.gui.btnInstall.connect('clicked', self.onBtnInstallClick)

    def onBtnAboutClick(self, widget, data = None):
        #self.gui.get_widget("aboutdialog").connect("delete_event", self.hidewindow)
        #self.gui.get_widget("aboutdialog").show()
		print "About"

    def hidewindow(self, w, event, data = None):
        w.hide()
        return True

    def onBtnUpgradeClick(self, widget, data = None):
        self.gui.window.hide()
        pkgMan.upgrade()
		self.gui.selectedPackages = []
        self.gui.window.show()

    def onBtnInstallClick(self, widget, data = None):
        self.gui.window.hide()
		instPacks = []
		for i in self.gui.selectedPackages:
			instPacks.extend(PackagesList.Packages.dependencies[i])
        pkgMan.install(instPacks)
        exConf.configs()
		self.gui.selectedPackages = []
        self.gui.window.show()

	def run(self):
		self.gui.main()

class ExtraConf:
    confdir = os.path.join(os.path.split(os.path.abspath(sys.argv[0]))[0],'conf')

    def configs(self):
        """ Do selected configuration tasks """
        registered = 0

		for self.element in ui.gui.selectedPackages:
			if self.element in ("extrafonts", "persianfonts", "xfardic", "sourceslist", "dma", "numlock", "ctrlaltdel"):
			# Unsafe practice
                       try:
                           selfmethod = getattr(self, self.element) # this would now be a reference to e.g. self.midi
                           selfmethod() # call it
                       except:
                           pass

    def register(self):
        """
        Registers gstreamer codecs, need to add dialog/log of command status
        """
        subprocess.Popen(["/usr/bin/gst-register-0.8"]).wait()

    def extrafonts(self):
        """ Install Microsoft Fonts """
        # Hardcoding
        retcode = subprocess.Popen(["tar", "xf", confdir+"/msttcorefonts.tar", "-C", "/usr/share/fonts/truetype/"]).wait()

    def persianfonts(self):
        """ Install Persian Fonts """
        # Hardcoding
        retcode = subprocess.Popen(["mkdir", "/usr/share/fonts/truetype/ttf-persian-fonts/"])
        retcode = subprocess.Popen(["tar", "-zxf", confdir+"/bfonts.tar.gz", "-C", "/usr/share/fonts/truetype/ttf-persian-fonts/"]).wait()
        retcode = subprocess.Popen(["tar", "-zxf", confdir+"/tahoma.tar.gz", "-C", "/usr/share/fonts/truetype/ttf-persian-fonts/"]).wait()

    def xfardic(self):
        """ Install xFarDic Multilingual Dictionary and It's DB files """
        # Hardcoding
        retcode = subprocess.Popen(["tar", "-zxf", confdir+"/generic.xdb.tar.gz", "-C", "/usr/share/xfardic-xdb/"]).wait()
        # Should Be Fixed! # retcode = subprocess.Popen(["cp", Do.confdir+"/xfardic", "/$HOME/xfardic"]).wait()
        #retcode = subprocess.Popen(["cp", Do.confdir+"/xfardic.desktop", "/usr/share/applications/xfardic.desktop"]).wait()

    def sourceslist(self):
        """ Replace the old sources.list by a new one"""
        # Hardcoding
        cmd.cp(confdir + "/sources.list", Out = "/etc/apt/sources.list")

    def dma(self):
        """ Add DMA support to hdparm.conf """
        # Hardcoding
        cmd.cp(confdir + "/hdparm.conf", Out = "/etc/hdparm.conf")

    def numlock(self):
        """ Run numlockx at GDM stratup """
        # Hardcoding
        cmd.cp(confdir + "/numlock-gdm", Out = "/etc/X11/gdm.Init/Default")

    def ctrlaltdel(self):
        """ Run gnome-system-monitor when you type Ctrl+Alt+Del """
        retcode = subprocess.Popen(["gconftool-2", "-t", "str", "--set", "/apps/metacity/global_keybindings/run_command_9", "<Control><Alt>Delete"]).wait()
        #print "gconftool exited with return code = ",retcode
        retcode = subprocess.Popen(["gconftool-2", "-t", "str", "--set", "/apps/metacity/keybinding_commands/command_9", "gnome-system-monitor"]).wait()
        #print "gconftool exited with return code = ",retcode

if __name__ == "__main__":
    basepath = os.path.split(os.path.abspath(sys.argv[0]))[0]
    confdir = os.path.join(basepath,'conf')
    #print basepath,confdir
    detect.replace(confdir)
    cmd = Utils()
    pkgMan = PackageManager()
    exConf = ExtraConf()
	packs = PackagesList.Packages(os.path.join(basepath, 'Packages.list'))
	packs.parse()
	packs.testInstalled()
    ui = MakeGui()
    ui.run()

